// stdafx.h : W̃VXe CN[h t@CA
//            ܂͎QƉ񐔂A܂ύXȂ
//            vWFNgp̃CN[h t@CLq܂B
//

#if !defined(AFX_STDAFX_H__B0C245C6_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_STDAFX_H__B0C245C6_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define VC_EXTRALEAN		// Windows wb_[wǎgpȂX^btO܂B

#include <afxwin.h>         // MFC ̃RAѕWR|[lg
#include <afxext.h>         // MFC ̊g
#include <afxdtctl.h>		// MFC  Internet Explorer 4 R Rg[ T|[g
#ifndef _AFX_NO_AFXCMN_SUPPORT
#include <afxcmn.h>			// MFC  Windows R Rg[ T|[g
#endif // _AFX_NO_AFXCMN_SUPPORT

#include <afxrich.h>
#include <stdio.h>
#include <fstream>

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_STDAFX_H__B0C245C6_42EA_11D5_B88C_00008659960F__INCLUDED_)
